from ..Classes.Agent import Agent
from ..Classes.ImplementatieElement.ActivityComplex import ActivityComplex
from ..Classes.ImplementatieElement.Bijlage import Bijlage
from ..Classes.ImplementatieElement.Derdenobject import Derdenobject
from ..Classes.ImplementatieElement.ElectricityAppurtenance import ElectricityAppurtenance
from ..Classes.ImplementatieElement.ElectricityCable import ElectricityCable
from ..Classes.ImplementatieElement.Pipe import Pipe
from ..Classes.ImplementatieElement.TelecommunicationsAppurtenance import TelecommunicationsAppurtenance
from ..Classes.ImplementatieElement.TelecommunicationsCable import TelecommunicationsCable
from ..Classes.ImplementatieElement.Toegangsprocedure import Toegangsprocedure
from ..Classes.Installatie.ASTRIDInstallatie import ASTRIDInstallatie
from ..Classes.Installatie.Aanslagbalk import Aanslagbalk
from ..Classes.Installatie.Aanvaarbescherming import Aanvaarbescherming
from ..Classes.Installatie.Aardingsinstallatie import Aardingsinstallatie
from ..Classes.Installatie.Aswegersite import Aswegersite
from ..Classes.Installatie.Baanlichaam import Baanlichaam
from ..Classes.Installatie.Balans import Balans
from ..Classes.Installatie.Balansarm import Balansarm
from ..Classes.Installatie.Balgmechanisme import Balgmechanisme
from ..Classes.Installatie.Balk import Balk
from ..Classes.Installatie.BasisverlichtingTunnel import BasisverlichtingTunnel
from ..Classes.Installatie.Been import Been
from ..Classes.Installatie.Berlinerwand import Berlinerwand
from ..Classes.Installatie.BeweegbareWaterkerendeConstructie import BeweegbareWaterkerendeConstructie
from ..Classes.Installatie.BiFlashInstallatie import BiFlashInstallatie
from ..Classes.Installatie.BinnenverlichtingGroep import BinnenverlichtingGroep
from ..Classes.Installatie.BlindePut import BlindePut
from ..Classes.Installatie.Bochtafbakeningsinstallatie import Bochtafbakeningsinstallatie
from ..Classes.Installatie.Bodembescherming import Bodembescherming
from ..Classes.Installatie.Boog import Boog
from ..Classes.Installatie.Bovenrolwagen import Bovenrolwagen
from ..Classes.Installatie.BrandblusserGroep import BrandblusserGroep
from ..Classes.Installatie.Breekbalk import Breekbalk
from ..Classes.Installatie.Brug import Brug
from ..Classes.Installatie.Brugballast import Brugballast
from ..Classes.Installatie.Brugdeel import Brugdeel
from ..Classes.Installatie.Brugdek import Brugdek
from ..Classes.Installatie.Brugligger import Brugligger
from ..Classes.Installatie.Bufferinstallatie import Bufferinstallatie
from ..Classes.Installatie.CalamiteitendoorsteekGroep import CalamiteitendoorsteekGroep
from ..Classes.Installatie.CameraGroep import CameraGroep
from ..Classes.Installatie.Centreermechanisme import Centreermechanisme
from ..Classes.Installatie.Combiwand import Combiwand
from ..Classes.Installatie.Damwand import Damwand
from ..Classes.Installatie.Deurkamer import Deurkamer
from ..Classes.Installatie.Deurkas import Deurkas
from ..Classes.Installatie.Deurloop import Deurloop
from ..Classes.Installatie.Deurnis import Deurnis
from ..Classes.Installatie.DraagstructuurBWCTWC import DraagstructuurBWCTWC
from ..Classes.Installatie.Drempel import Drempel
from ..Classes.Installatie.DrogePompkelder import DrogePompkelder
from ..Classes.Installatie.Dukdalf import Dukdalf
from ..Classes.Installatie.DynBordGroep import DynBordGroep
from ..Classes.Installatie.Ecoduct import Ecoduct
from ..Classes.Installatie.Ecoduiker import Ecoduiker
from ..Classes.Installatie.Ecokoker import Ecokoker
from ..Classes.Installatie.Ecotunnel import Ecotunnel
from ..Classes.Installatie.Ecovallei import Ecovallei
from ..Classes.Installatie.ExterneNaspanning import ExterneNaspanning
from ..Classes.Installatie.Fietstelinstallatie import Fietstelinstallatie
from ..Classes.Installatie.Flitsgroep import Flitsgroep
from ..Classes.Installatie.Flitspaal import Flitspaal
from ..Classes.Installatie.Fuik import Fuik
from ..Classes.Installatie.Funderingswand import Funderingswand
from ..Classes.Installatie.Gebouw import Gebouw
from ..Classes.Installatie.GecombineerdePut import GecombineerdePut
from ..Classes.Installatie.Geleidewerk import Geleidewerk
from ..Classes.Installatie.GeluidwerendeConstructie import GeluidwerendeConstructie
from ..Classes.Installatie.GewapendeGrond import GewapendeGrond
from ..Classes.Installatie.Gewelf import Gewelf
from ..Classes.Installatie.Gewichtsmuur import Gewichtsmuur
from ..Classes.Installatie.Glijgeleiding import Glijgeleiding
from ..Classes.Installatie.Gording import Gording
from ..Classes.Installatie.Grendelmechanisme import Grendelmechanisme
from ..Classes.Installatie.GroepDwarseMarkeringEnFiguratie import GroepDwarseMarkeringEnFiguratie
from ..Classes.Installatie.GroepMarkering import GroepMarkering
from ..Classes.Installatie.Gronddam import Gronddam
from ..Classes.Installatie.Grondverbetering import Grondverbetering
from ..Classes.Installatie.Halsbeugelmechanisme import Halsbeugelmechanisme
from ..Classes.Installatie.Hameipoort import Hameipoort
from ..Classes.Installatie.Hameistijl import Hameistijl
from ..Classes.Installatie.Hanger import Hanger
from ..Classes.Installatie.Hefportiek import Hefportiek
from ..Classes.Installatie.Heftoren import Heftoren
from ..Classes.Installatie.HoogtebegrenzerInstallatie import HoogtebegrenzerInstallatie
from ..Classes.Installatie.HorizontaleConstructieplaat import HorizontaleConstructieplaat
from ..Classes.Installatie.Hulppost import Hulppost
from ..Classes.Installatie.HulppostGroep import HulppostGroep
from ..Classes.Installatie.HydraulischeCilinder import HydraulischeCilinder
from ..Classes.Installatie.IPBackbone import IPBackbone
from ..Classes.Installatie.IVSBGroep import IVSBGroep
from ..Classes.Installatie.InspectieputRiolering import InspectieputRiolering
from ..Classes.Installatie.Kabelbewegingsmechanisme import Kabelbewegingsmechanisme
from ..Classes.Installatie.Kabelkoker import Kabelkoker
from ..Classes.Installatie.Kabelveerhuis import Kabelveerhuis
from ..Classes.Installatie.Kelderlandhoofd import Kelderlandhoofd
from ..Classes.Installatie.Kelderpijler import Kelderpijler
from ..Classes.Installatie.Kesp import Kesp
from ..Classes.Installatie.Koker import Koker
from ..Classes.Installatie.Kokerafsluiting import Kokerafsluiting
from ..Classes.Installatie.Kokercomplex import Kokercomplex
from ..Classes.Installatie.Kokersectie import Kokersectie
from ..Classes.Installatie.Kokerventilatie import Kokerventilatie
from ..Classes.Installatie.Kolk import Kolk
from ..Classes.Installatie.Kolkvloer import Kolkvloer
from ..Classes.Installatie.Kolkwand import Kolkwand
from ..Classes.Installatie.Kolom import Kolom
from ..Classes.Installatie.Koppelbalk import Koppelbalk
from ..Classes.Installatie.Koppeling import Koppeling
from ..Classes.Installatie.L2AccessStructuur import L2AccessStructuur
from ..Classes.Installatie.LEDRotondeafbakening import LEDRotondeafbakening
from ..Classes.Installatie.LEDWegdekreflectorBebakening import LEDWegdekreflectorBebakening
from ..Classes.Installatie.Landhoofd import Landhoofd
from ..Classes.Installatie.Leuning import Leuning
from ..Classes.Installatie.Link import Link
from ..Classes.Installatie.Lmuur import Lmuur
from ..Classes.Installatie.Lokaal import Lokaal
from ..Classes.Installatie.Luchtkwaliteitsensor import Luchtkwaliteitsensor
from ..Classes.Installatie.MIVInstallatie import MIVInstallatie
from ..Classes.Installatie.MIVMeetpunt import MIVMeetpunt
from ..Classes.Installatie.MIVModule import MIVModule
from ..Classes.Installatie.MVPaal import MVPaal
from ..Classes.Installatie.Matrixbord import Matrixbord
from ..Classes.Installatie.MechanischeCilinder import MechanischeCilinder
from ..Classes.Installatie.Meetstation import Meetstation
from ..Classes.Installatie.Meteostation import Meteostation
from ..Classes.Installatie.Omloopriool import Omloopriool
from ..Classes.Installatie.Omroepzone import Omroepzone
from ..Classes.Installatie.Onderbord import Onderbord
from ..Classes.Installatie.Onderrolwagen import Onderrolwagen
from ..Classes.Installatie.Oplegmechanisme import Oplegmechanisme
from ..Classes.Installatie.Oplegrij import Oplegrij
from ..Classes.Installatie.Overbrenging import Overbrenging
from ..Classes.Installatie.Paalmatras import Paalmatras
from ..Classes.Installatie.Pad import Pad
from ..Classes.Installatie.Pijler import Pijler
from ..Classes.Installatie.PompGroep import PompGroep
from ..Classes.Installatie.Pompkamer import Pompkamer
from ..Classes.Installatie.Pompstation import Pompstation
from ..Classes.Installatie.Pyloon import Pyloon
from ..Classes.Installatie.RadioheruitzendInstallatie import RadioheruitzendInstallatie
from ..Classes.Installatie.Randprofiel import Randprofiel
from ..Classes.Installatie.Rioleringsstelsel import Rioleringsstelsel
from ..Classes.Installatie.Rolgeleiding import Rolgeleiding
from ..Classes.Installatie.Scharnierpunt import Scharnierpunt
from ..Classes.Installatie.SecansTangenspalenwand import SecansTangenspalenwand
from ..Classes.Installatie.Slagboom import Slagboom
from ..Classes.Installatie.SlagboomGroep import SlagboomGroep
from ..Classes.Installatie.Sluis import Sluis
from ..Classes.Installatie.Sluishoofd import Sluishoofd
from ..Classes.Installatie.Soilmixwand import Soilmixwand
from ..Classes.Installatie.Spindelmechanisme import Spindelmechanisme
from ..Classes.Installatie.StalenCaisson import StalenCaisson
from ..Classes.Installatie.StalenFunderingsprofiel import StalenFunderingsprofiel
from ..Classes.Installatie.Stangenmechanisme import Stangenmechanisme
from ..Classes.Installatie.Stuw import Stuw
from ..Classes.Installatie.Stuwhoofd import Stuwhoofd
from ..Classes.Installatie.Taatsmechanisme import Taatsmechanisme
from ..Classes.Installatie.Tandheugelmechanisme import Tandheugelmechanisme
from ..Classes.Installatie.Tandkransmechanisme import Tandkransmechanisme
from ..Classes.Installatie.Tegengewichtkist import Tegengewichtkist
from ..Classes.Installatie.TijdelijkeBerlinerwandTussenschot import TijdelijkeBerlinerwandTussenschot
from ..Classes.Installatie.TijdelijkeOpslagplaats import TijdelijkeOpslagplaats
from ..Classes.Installatie.TijdelijkeWaterkerendeConstructie import TijdelijkeWaterkerendeConstructie
from ..Classes.Installatie.Trajectcontrole import Trajectcontrole
from ..Classes.Installatie.Trappentoren import Trappentoren
from ..Classes.Installatie.Trekker import Trekker
from ..Classes.Installatie.Tunneluitrusting import Tunneluitrusting
from ..Classes.Installatie.Tunnelverlichting import Tunnelverlichting
from ..Classes.Installatie.VLAN import VLAN
from ..Classes.Installatie.VakwerkElement import VakwerkElement
from ..Classes.Installatie.VasteWaterbouwkundigeConstructie import VasteWaterbouwkundigeConstructie
from ..Classes.Installatie.Ventilatiecluster import Ventilatiecluster
from ..Classes.Installatie.Ventilatiekanaal import Ventilatiekanaal
from ..Classes.Installatie.Verdeelbalk import Verdeelbalk
from ..Classes.Installatie.VerkeersbordConcept import VerkeersbordConcept
from ..Classes.Installatie.VerkeersbordVerkeersteken import VerkeersbordVerkeersteken
from ..Classes.Installatie.Verkeersbordopstelling import Verkeersbordopstelling
from ..Classes.Installatie.VerlichteOversteekplaatsGroep import VerlichteOversteekplaatsGroep
from ..Classes.Installatie.VernageldeWand import VernageldeWand
from ..Classes.Installatie.VersterkingsverlichtingTunnel import VersterkingsverlichtingTunnel
from ..Classes.Installatie.Vloernis import Vloernis
from ..Classes.Installatie.Vluchtdeurindicatie import Vluchtdeurindicatie
from ..Classes.Installatie.Vluchtganginrichting import Vluchtganginrichting
from ..Classes.Installatie.Vluchtgeleiding import Vluchtgeleiding
from ..Classes.Installatie.Vluchtroute import Vluchtroute
from ..Classes.Installatie.VoorzieningNegatieveReactie import VoorzieningNegatieveReactie
from ..Classes.Installatie.Wand import Wand
from ..Classes.Installatie.WaterdoorvoerendeDuiker import WaterdoorvoerendeDuiker
from ..Classes.Installatie.Waterweg import Waterweg
from ..Classes.Installatie.Wegberm import Wegberm
from ..Classes.Installatie.Weguitrusting import Weguitrusting
from ..Classes.Installatie.Wilddetectiezone import Wilddetectiezone
from ..Classes.Installatie.Windverband import Windverband
from ..Classes.Installatie.Wrijfbalk import Wrijfbalk
from ..Classes.Installatie.Z30Groep import Z30Groep
from ..Classes.Installatie.Zoutbijlaadplaats import Zoutbijlaadplaats
from ..Classes.Installatie.Zpad import Zpad
from ..Classes.Levenscyclus.Afdekking import Afdekking
from ..Classes.Levenscyclus.Afgraving import Afgraving
from ..Classes.Levenscyclus.BeheerBoomvorm import BeheerBoomvorm
from ..Classes.Levenscyclus.BeheerExoten import BeheerExoten
from ..Classes.Levenscyclus.BeheerGrazigeVegetatie import BeheerGrazigeVegetatie
from ..Classes.Levenscyclus.BeheerHoutigeVegetatie import BeheerHoutigeVegetatie
from ..Classes.Levenscyclus.BeheerSierbeplanting import BeheerSierbeplanting
from ..Classes.Levenscyclus.Bemesting import Bemesting
from ..Classes.Levenscyclus.Bodemverbeteringsmiddel import Bodemverbeteringsmiddel
from ..Classes.Levenscyclus.Grondbewerking import Grondbewerking
from ..Classes.Levenscyclus.Ophoging import Ophoging
from ..Classes.Levenscyclus.Uitgraving import Uitgraving
from ..Classes.Onderdeel.AIDModule import AIDModule
from ..Classes.Onderdeel.ANPRCamera import ANPRCamera
from ..Classes.Onderdeel.Aandrijfas import Aandrijfas
from ..Classes.Onderdeel.Aangrijpingsstoel import Aangrijpingsstoel
from ..Classes.Onderdeel.Aansluitmof import Aansluitmof
from ..Classes.Onderdeel.Aansluitopening import Aansluitopening
from ..Classes.Onderdeel.Aanstraalverlichting import Aanstraalverlichting
from ..Classes.Onderdeel.AanvullendeGeometrie import AanvullendeGeometrie
from ..Classes.Onderdeel.AanvullendeMiddellijn import AanvullendeMiddellijn
from ..Classes.Onderdeel.Aardingskabel import Aardingskabel
from ..Classes.Onderdeel.Aardingslus import Aardingslus
from ..Classes.Onderdeel.Aardingsonderbreker import Aardingsonderbreker
from ..Classes.Onderdeel.Aardingspen import Aardingspen
from ..Classes.Onderdeel.Aardingsplaat import Aardingsplaat
from ..Classes.Onderdeel.AfdekplaatBuispaal import AfdekplaatBuispaal
from ..Classes.Onderdeel.Afdichting import Afdichting
from ..Classes.Onderdeel.Afdichtingsvoorziening import Afdichtingsvoorziening
from ..Classes.Onderdeel.Afmetingsensor import Afmetingsensor
from ..Classes.Onderdeel.Afscherming import Afscherming
from ..Classes.Onderdeel.Afsluiter import Afsluiter
from ..Classes.Onderdeel.Afsluiting import Afsluiting
from ..Classes.Onderdeel.Afsluitkraan import Afsluitkraan
from ..Classes.Onderdeel.Aftakking import Aftakking
from ..Classes.Onderdeel.Afwateringsgeul import Afwateringsgeul
from ..Classes.Onderdeel.AlarmModule import AlarmModule
from ..Classes.Onderdeel.AnalogeHoppinzuil import AnalogeHoppinzuil
from ..Classes.Onderdeel.Ankerplaat import Ankerplaat
from ..Classes.Onderdeel.Ankerstang import Ankerstang
from ..Classes.Onderdeel.Antenne import Antenne
from ..Classes.Onderdeel.Antennecoupler import Antennecoupler
from ..Classes.Onderdeel.AntiParkeerpaal import AntiParkeerpaal
from ..Classes.Onderdeel.Armatuurcontroller import Armatuurcontroller
from ..Classes.Onderdeel.AsMechanisch import AsMechanisch
from ..Classes.Onderdeel.Asfaltmat import Asfaltmat
from ..Classes.Onderdeel.Aswegerput import Aswegerput
from ..Classes.Onderdeel.Audioversterker import Audioversterker
from ..Classes.Onderdeel.AutomatischeOmschakelaar import AutomatischeOmschakelaar
from ..Classes.Onderdeel.Badgelezer import Badgelezer
from ..Classes.Onderdeel.Balg import Balg
from ..Classes.Onderdeel.Ballastcompartiment import Ballastcompartiment
from ..Classes.Onderdeel.Baret import Baret
from ..Classes.Onderdeel.Batterij import Batterij
from ..Classes.Onderdeel.Batterijlader import Batterijlader
from ..Classes.Onderdeel.Bel import Bel
from ..Classes.Onderdeel.Beschermbuis import Beschermbuis
from ..Classes.Onderdeel.BeschermingWapening import BeschermingWapening
from ..Classes.Onderdeel.Beschermlaag import Beschermlaag
from ..Classes.Onderdeel.BeslagHoutenSluisdeur import BeslagHoutenSluisdeur
from ..Classes.Onderdeel.BestratingVanBetonstraatsteen import BestratingVanBetonstraatsteen
from ..Classes.Onderdeel.BestratingVanBetontegel import BestratingVanBetontegel
from ..Classes.Onderdeel.BestratingVanGebakkenStraatsteen import BestratingVanGebakkenStraatsteen
from ..Classes.Onderdeel.BestratingVanGrasbetontegel import BestratingVanGrasbetontegel
from ..Classes.Onderdeel.BestratingVanKassei import BestratingVanKassei
from ..Classes.Onderdeel.BestratingVanMozaiekkei import BestratingVanMozaiekkei
from ..Classes.Onderdeel.BestratingVanNatuursteentegel import BestratingVanNatuursteentegel
from ..Classes.Onderdeel.Bestrijking import Bestrijking
from ..Classes.Onderdeel.Betonmat import Betonmat
from ..Classes.Onderdeel.Betonmatras import Betonmatras
from ..Classes.Onderdeel.BetonnenBoorpaal import BetonnenBoorpaal
from ..Classes.Onderdeel.BetonnenCaison import BetonnenCaison
from ..Classes.Onderdeel.BetonnenConstructieObject import BetonnenConstructieObject
from ..Classes.Onderdeel.BetonnenDamplank import BetonnenDamplank
from ..Classes.Onderdeel.BetonnenHeipaal import BetonnenHeipaal
from ..Classes.Onderdeel.BetonnenPlaat import BetonnenPlaat
from ..Classes.Onderdeel.BetonnenPredal import BetonnenPredal
from ..Classes.Onderdeel.BetonnenProfiel import BetonnenProfiel
from ..Classes.Onderdeel.BetonnenSchroefpaal import BetonnenSchroefpaal
from ..Classes.Onderdeel.Bevestiging import Bevestiging
from ..Classes.Onderdeel.Bevestigingsbeugel import Bevestigingsbeugel
from ..Classes.Onderdeel.Bevestigingssteun import Bevestigingssteun
from ..Classes.Onderdeel.Bewegingssensor import Bewegingssensor
from ..Classes.Onderdeel.BiFlash import BiFlash
from ..Classes.Onderdeel.Bijlage import Bijlage
from ..Classes.Onderdeel.BijzonderGeluidsschermelement import BijzonderGeluidsschermelement
from ..Classes.Onderdeel.Binnenverlichtingstoestel import Binnenverlichtingstoestel
from ..Classes.Onderdeel.BitumineuzeLaag import BitumineuzeLaag
from ..Classes.Onderdeel.Bliksemafleider import Bliksemafleider
from ..Classes.Onderdeel.BloemrijkGlanshavergrasland import BloemrijkGlanshavergrasland
from ..Classes.Onderdeel.BloemrijkGraslandGraslandfase4 import BloemrijkGraslandGraslandfase4
from ..Classes.Onderdeel.BloemrijkStruisgrasgrasland import BloemrijkStruisgrasgrasland
from ..Classes.Onderdeel.BloemrijkVochtigTotNatGrasland import BloemrijkVochtigTotNatGrasland
from ..Classes.Onderdeel.Bolder import Bolder
from ..Classes.Onderdeel.BoogpaalVerkeerslicht import BoogpaalVerkeerslicht
from ..Classes.Onderdeel.Boom import Boom
from ..Classes.Onderdeel.Boombrug import Boombrug
from ..Classes.Onderdeel.Bouwput import Bouwput
from ..Classes.Onderdeel.Bovenbouw import Bovenbouw
from ..Classes.Onderdeel.Braam import Braam
from ..Classes.Onderdeel.Brandblusser import Brandblusser
from ..Classes.Onderdeel.Brandhaspel import Brandhaspel
from ..Classes.Onderdeel.Brandleiding import Brandleiding
from ..Classes.Onderdeel.Brandnetelruigte import Brandnetelruigte
from ..Classes.Onderdeel.Breedplaat import Breedplaat
from ..Classes.Onderdeel.BremEnGaspeldoornstruweel import BremEnGaspeldoornstruweel
from ..Classes.Onderdeel.Brugdekvoeg import Brugdekvoeg
from ..Classes.Onderdeel.Buffercilinder import Buffercilinder
from ..Classes.Onderdeel.Buisbekleding import Buisbekleding
from ..Classes.Onderdeel.BusMechanisch import BusMechanisch
from ..Classes.Onderdeel.BypassSchakelaar import BypassSchakelaar
from ..Classes.Onderdeel.CFAPaal import CFAPaal
from ..Classes.Onderdeel.Cabine import Cabine
from ..Classes.Onderdeel.Cabinecontroller import Cabinecontroller
from ..Classes.Onderdeel.Calamiteitendoorsteek import Calamiteitendoorsteek
from ..Classes.Onderdeel.CalamiteitsBord import CalamiteitsBord
from ..Classes.Onderdeel.Camera import Camera
from ..Classes.Onderdeel.CapacitieveNiveaumeting import CapacitieveNiveaumeting
from ..Classes.Onderdeel.CementBentonietwand import CementBentonietwand
from ..Classes.Onderdeel.Cementbetonverharding import Cementbetonverharding
from ..Classes.Onderdeel.Centreerinrichting import Centreerinrichting
from ..Classes.Onderdeel.Centreervork import Centreervork
from ..Classes.Onderdeel.CilinderStangkop import CilinderStangkop
from ..Classes.Onderdeel.Cilinderbodem import Cilinderbodem
from ..Classes.Onderdeel.Cilinderkop import Cilinderkop
from ..Classes.Onderdeel.Cilindermantel import Cilindermantel
from ..Classes.Onderdeel.Cilinderstang import Cilinderstang
from ..Classes.Onderdeel.Cilinderzuiger import Cilinderzuiger
from ..Classes.Onderdeel.Cluster import Cluster
from ..Classes.Onderdeel.Codeklavier import Codeklavier
from ..Classes.Onderdeel.ColloidaalBeton import ColloidaalBeton
from ..Classes.Onderdeel.Combilantaarn import Combilantaarn
from ..Classes.Onderdeel.ConstructieSokkel import ConstructieSokkel
from ..Classes.Onderdeel.Contactor import Contactor
from ..Classes.Onderdeel.Contactpunt import Contactpunt
from ..Classes.Onderdeel.Container import Container
from ..Classes.Onderdeel.Contourverlichting import Contourverlichting
from ..Classes.Onderdeel.Controlepaneel import Controlepaneel
from ..Classes.Onderdeel.DABRepeater import DABRepeater
from ..Classes.Onderdeel.DNBHoogspanning import DNBHoogspanning
from ..Classes.Onderdeel.DNBLaagspanning import DNBLaagspanning
from ..Classes.Onderdeel.Damwand import Damwand
from ..Classes.Onderdeel.Datakabel import Datakabel
from ..Classes.Onderdeel.Dekzerkprofiel import Dekzerkprofiel
from ..Classes.Onderdeel.DetectieCamera import DetectieCamera
from ..Classes.Onderdeel.Detectieverwerkingseenheid import Detectieverwerkingseenheid
from ..Classes.Onderdeel.Deur import Deur
from ..Classes.Onderdeel.Dichting import Dichting
from ..Classes.Onderdeel.Dieptetemperatuursensor import Dieptetemperatuursensor
from ..Classes.Onderdeel.Diepwand import Diepwand
from ..Classes.Onderdeel.Dieselgenerator import Dieselgenerator
from ..Classes.Onderdeel.DigitaleHoppinzuil import DigitaleHoppinzuil
from ..Classes.Onderdeel.Dilatatie import Dilatatie
from ..Classes.Onderdeel.Display import Display
from ..Classes.Onderdeel.Divergentiepuntbebakeningselement import Divergentiepuntbebakeningselement
from ..Classes.Onderdeel.Dolomietverharding import Dolomietverharding
from ..Classes.Onderdeel.DominantGraslandfase2 import DominantGraslandfase2
from ..Classes.Onderdeel.Dompelpomp import Dompelpomp
from ..Classes.Onderdeel.Dongle import Dongle
from ..Classes.Onderdeel.Doorgang import Doorgang
from ..Classes.Onderdeel.Doornstruweel import Doornstruweel
from ..Classes.Onderdeel.Doorverbinddoos import Doorverbinddoos
from ..Classes.Onderdeel.Draagkabel import Draagkabel
from ..Classes.Onderdeel.Draagstoel import Draagstoel
from ..Classes.Onderdeel.Draineerbuis import Draineerbuis
from ..Classes.Onderdeel.Draineerlaag import Draineerlaag
from ..Classes.Onderdeel.Drukknop import Drukknop
from ..Classes.Onderdeel.Druklaag import Druklaag
from ..Classes.Onderdeel.Drukvat import Drukvat
from ..Classes.Onderdeel.Drukverhogingsgroep import Drukverhogingsgroep
from ..Classes.Onderdeel.Duikschot import Duikschot
from ..Classes.Onderdeel.Duingrasland import Duingrasland
from ..Classes.Onderdeel.DunneOverlaging import DunneOverlaging
from ..Classes.Onderdeel.DwarseMarkering import DwarseMarkering
from ..Classes.Onderdeel.DwarseMarkeringVerschuind import DwarseMarkeringVerschuind
from ..Classes.Onderdeel.Dwerghavergrasland import Dwerghavergrasland
from ..Classes.Onderdeel.DwergstruikvegetatieHeidesoorten import DwergstruikvegetatieHeidesoorten
from ..Classes.Onderdeel.DynBordExternePU import DynBordExternePU
from ..Classes.Onderdeel.DynBordOpMaat import DynBordOpMaat
from ..Classes.Onderdeel.DynBordPK import DynBordPK
from ..Classes.Onderdeel.DynBordRSS import DynBordRSS
from ..Classes.Onderdeel.DynBordRVMS import DynBordRVMS
from ..Classes.Onderdeel.DynBordVMS import DynBordVMS
from ..Classes.Onderdeel.DynBordZ30 import DynBordZ30
from ..Classes.Onderdeel.DynamischeVluchtwegindicatie import DynamischeVluchtwegindicatie
from ..Classes.Onderdeel.EcoPoort import EcoPoort
from ..Classes.Onderdeel.Ecoraster import Ecoraster
from ..Classes.Onderdeel.Eindstuk import Eindstuk
from ..Classes.Onderdeel.ElastischElement import ElastischElement
from ..Classes.Onderdeel.Elektromotor import Elektromotor
from ..Classes.Onderdeel.EnergiemeterAWV import EnergiemeterAWV
from ..Classes.Onderdeel.EnergiemeterDNB import EnergiemeterDNB
from ..Classes.Onderdeel.EnergiemeterDNBPiek import EnergiemeterDNBPiek
from ..Classes.Onderdeel.EnergiemeterDNBReactief import EnergiemeterDNBReactief
from ..Classes.Onderdeel.EnergiemeterDerden import EnergiemeterDerden
from ..Classes.Onderdeel.EquipotentiaalVerbinding import EquipotentiaalVerbinding
from ..Classes.Onderdeel.Evenaar import Evenaar
from ..Classes.Onderdeel.Exoten import Exoten
from ..Classes.Onderdeel.ExterneDetectie import ExterneDetectie
from ..Classes.Onderdeel.FMRepeaterBox import FMRepeaterBox
from ..Classes.Onderdeel.Fendering import Fendering
from ..Classes.Onderdeel.FieldOfView import FieldOfView
from ..Classes.Onderdeel.Fietslantaarn import Fietslantaarn
from ..Classes.Onderdeel.FietstelDisplay import FietstelDisplay
from ..Classes.Onderdeel.Fietstelsysteem import Fietstelsysteem
from ..Classes.Onderdeel.FiguratieMarkering import FiguratieMarkering
from ..Classes.Onderdeel.FiguratieMarkeringVerschuind import FiguratieMarkeringVerschuind
from ..Classes.Onderdeel.Flens import Flens
from ..Classes.Onderdeel.Flenskoppeling import Flenskoppeling
from ..Classes.Onderdeel.Flitscamera import Flitscamera
from ..Classes.Onderdeel.ForfaitaireAansluiting import ForfaitaireAansluiting
from ..Classes.Onderdeel.FunderingOpStaal import FunderingOpStaal
from ..Classes.Onderdeel.Funderingsmassief import Funderingsmassief
from ..Classes.Onderdeel.Funderingspaal import Funderingspaal
from ..Classes.Onderdeel.Funderingsplaat import Funderingsplaat
from ..Classes.Onderdeel.Funderingsput import Funderingsput
from ..Classes.Onderdeel.Funderingszool import Funderingszool
from ..Classes.Onderdeel.GPU import GPU
from ..Classes.Onderdeel.Galgpaal import Galgpaal
from ..Classes.Onderdeel.Gassensor import Gassensor
from ..Classes.Onderdeel.GeexpandeerdPolystyreen import GeexpandeerdPolystyreen
from ..Classes.Onderdeel.GekleurdWegvlakMarkering import GekleurdWegvlakMarkering
from ..Classes.Onderdeel.Geleideconstructie import Geleideconstructie
from ..Classes.Onderdeel.Geleidingsverlichting import Geleidingsverlichting
from ..Classes.Onderdeel.Geleidingswand import Geleidingswand
from ..Classes.Onderdeel.GeluidswerendeConstructie import GeluidswerendeConstructie
from ..Classes.Onderdeel.Geotextiel import Geotextiel
from ..Classes.Onderdeel.GetesteBeginconstructie import GetesteBeginconstructie
from ..Classes.Onderdeel.Glijlager import Glijlager
from ..Classes.Onderdeel.Glijmateriaal import Glijmateriaal
from ..Classes.Onderdeel.Golfplaat import Golfplaat
from ..Classes.Onderdeel.Gracht import Gracht
from ..Classes.Onderdeel.GrasKruidenmixGraslandfase3 import GrasKruidenmixGraslandfase3
from ..Classes.Onderdeel.Grasland import Grasland
from ..Classes.Onderdeel.Grasmat import Grasmat
from ..Classes.Onderdeel.GrassenmixGraslandfase1 import GrassenmixGraslandfase1
from ..Classes.Onderdeel.Grendel import Grendel
from ..Classes.Onderdeel.Grindgazon import Grindgazon
from ..Classes.Onderdeel.Grindkern import Grindkern
from ..Classes.Onderdeel.Grond import Grond
from ..Classes.Onderdeel.GrondankerVerdeelplaat import GrondankerVerdeelplaat
from ..Classes.Onderdeel.Groutanker import Groutanker
from ..Classes.Onderdeel.Groutpaal import Groutpaal
from ..Classes.Onderdeel.HSBeveiligingscel import HSBeveiligingscel
from ..Classes.Onderdeel.HSCabine import HSCabine
from ..Classes.Onderdeel.Haag import Haag
from ..Classes.Onderdeel.Haalkom import Haalkom
from ..Classes.Onderdeel.Halsbeugeloog import Halsbeugeloog
from ..Classes.Onderdeel.Halsbeugelpen import Halsbeugelpen
from ..Classes.Onderdeel.Halsbeugelschoen import Halsbeugelschoen
from ..Classes.Onderdeel.Handbediening import Handbediening
from ..Classes.Onderdeel.Handwiel import Handwiel
from ..Classes.Onderdeel.Hardware import Hardware
from ..Classes.Onderdeel.HeeftAanvullendeGeometrie import HeeftAanvullendeGeometrie
from ..Classes.Onderdeel.HeeftBeheer import HeeftBeheer
from ..Classes.Onderdeel.HeeftBetrokkene import HeeftBetrokkene
from ..Classes.Onderdeel.HeeftBijlage import HeeftBijlage
from ..Classes.Onderdeel.HeeftNetwerkProtectie import HeeftNetwerkProtectie
from ..Classes.Onderdeel.HeeftNetwerktoegang import HeeftNetwerktoegang
from ..Classes.Onderdeel.HeeftToegangsprocedure import HeeftToegangsprocedure
from ..Classes.Onderdeel.Heestermassief import Heestermassief
from ..Classes.Onderdeel.HeischraalGrasland import HeischraalGrasland
from ..Classes.Onderdeel.Hijsinstallatie import Hijsinstallatie
from ..Classes.Onderdeel.Hoofdschakelaar import Hoofdschakelaar
from ..Classes.Onderdeel.Hoogtebegrenzer import Hoogtebegrenzer
from ..Classes.Onderdeel.Hoogtedetectie import Hoogtedetectie
from ..Classes.Onderdeel.HoortBij import HoortBij
from ..Classes.Onderdeel.Houdriem import Houdriem
from ..Classes.Onderdeel.HoutenBeplanking import HoutenBeplanking
from ..Classes.Onderdeel.HoutenConstructieprofiel import HoutenConstructieprofiel
from ..Classes.Onderdeel.HoutenDamplank import HoutenDamplank
from ..Classes.Onderdeel.HoutenHeipaal import HoutenHeipaal
from ..Classes.Onderdeel.Huisaansluitput import Huisaansluitput
from ..Classes.Onderdeel.Hulppostkast import Hulppostkast
from ..Classes.Onderdeel.Hulpstuk import Hulpstuk
from ..Classes.Onderdeel.Huls import Huls
from ..Classes.Onderdeel.Hydrant import Hydrant
from ..Classes.Onderdeel.HydrostatischeNiveaumeting import HydrostatischeNiveaumeting
from ..Classes.Onderdeel.IOKaart import IOKaart
from ..Classes.Onderdeel.ITSapp import ITSapp
from ..Classes.Onderdeel.IVSB import IVSB
from ..Classes.Onderdeel.Iepenstruweel import Iepenstruweel
from ..Classes.Onderdeel.Illuminator import Illuminator
from ..Classes.Onderdeel.IndoorKast import IndoorKast
from ..Classes.Onderdeel.Infiltratievoorziening import Infiltratievoorziening
from ..Classes.Onderdeel.Injectiepaal import Injectiepaal
from ..Classes.Onderdeel.IntercomServer import IntercomServer
from ..Classes.Onderdeel.IntercomToestel import IntercomToestel
from ..Classes.Onderdeel.InvasieveExoten import InvasieveExoten
from ..Classes.Onderdeel.InwendigVerlichtPictogram import InwendigVerlichtPictogram
from ..Classes.Onderdeel.IoTSensor import IoTSensor
from ..Classes.Onderdeel.IpPowerSwitch import IpPowerSwitch
from ..Classes.Onderdeel.IsAdmOnderdeelVan import IsAdmOnderdeelVan
from ..Classes.Onderdeel.IsInspectieVan import IsInspectieVan
from ..Classes.Onderdeel.IsNetwerkECC import IsNetwerkECC
from ..Classes.Onderdeel.IsSWGehostOp import IsSWGehostOp
from ..Classes.Onderdeel.IsSWOnderdeelVan import IsSWOnderdeelVan
from ..Classes.Onderdeel.Kabelgoot import Kabelgoot
from ..Classes.Onderdeel.Kabelladder import Kabelladder
from ..Classes.Onderdeel.Kabelmof import Kabelmof
from ..Classes.Onderdeel.KabelnetBuis import KabelnetBuis
from ..Classes.Onderdeel.KabelnetToegang import KabelnetToegang
from ..Classes.Onderdeel.Kabelspanner import Kabelspanner
from ..Classes.Onderdeel.Kabelsteun import Kabelsteun
from ..Classes.Onderdeel.Kabeltrommel import Kabeltrommel
from ..Classes.Onderdeel.Kalkgrasland import Kalkgrasland
from ..Classes.Onderdeel.KalkrijkKamgrasland import KalkrijkKamgrasland
from ..Classes.Onderdeel.Kamer import Kamer
from ..Classes.Onderdeel.KantstrookAfw import KantstrookAfw
from ..Classes.Onderdeel.KantstrookStd import KantstrookStd
from ..Classes.Onderdeel.Keerwiel import Keerwiel
from ..Classes.Onderdeel.Klemsysteem import Klemsysteem
from ..Classes.Onderdeel.Klimatisatie import Klimatisatie
from ..Classes.Onderdeel.Klimvorm import Klimvorm
from ..Classes.Onderdeel.Knipperlantaarn import Knipperlantaarn
from ..Classes.Onderdeel.Kokervoeg import Kokervoeg
from ..Classes.Onderdeel.Kopmuur import Kopmuur
from ..Classes.Onderdeel.KringsBerliner import KringsBerliner
from ..Classes.Onderdeel.Kruk import Kruk
from ..Classes.Onderdeel.KunststoffenDamplank import KunststoffenDamplank
from ..Classes.Onderdeel.LEDDriver import LEDDriver
from ..Classes.Onderdeel.LKSensorDoorverbinddoos import LKSensorDoorverbinddoos
from ..Classes.Onderdeel.Laagspanningsbord import Laagspanningsbord
from ..Classes.Onderdeel.Ladder import Ladder
from ..Classes.Onderdeel.Lagerblok import Lagerblok
from ..Classes.Onderdeel.Lensplaat import Lensplaat
from ..Classes.Onderdeel.LetterCijferMarkering import LetterCijferMarkering
from ..Classes.Onderdeel.LetterMarkeringVerschaald import LetterMarkeringVerschaald
from ..Classes.Onderdeel.Lichtmast import Lichtmast
from ..Classes.Onderdeel.Lichtnagel import Lichtnagel
from ..Classes.Onderdeel.Lichtsensor import Lichtsensor
from ..Classes.Onderdeel.Lichtzuil import Lichtzuil
from ..Classes.Onderdeel.LigtOp import LigtOp
from ..Classes.Onderdeel.LijnvormigElementMarkering import LijnvormigElementMarkering
from ..Classes.Onderdeel.Lockerkast import Lockerkast
from ..Classes.Onderdeel.Lockermanagementmodule import Lockermanagementmodule
from ..Classes.Onderdeel.LogischePoort import LogischePoort
from ..Classes.Onderdeel.Loofhout import Loofhout
from ..Classes.Onderdeel.LoopTerminationAndProtection import LoopTerminationAndProtection
from ..Classes.Onderdeel.Loopvloer import Loopvloer
from ..Classes.Onderdeel.LuchtkwaliteitControleUnit import LuchtkwaliteitControleUnit
from ..Classes.Onderdeel.LuchtkwaliteitZenderOntvanger import LuchtkwaliteitZenderOntvanger
from ..Classes.Onderdeel.Luchtkwaliteitreflector import Luchtkwaliteitreflector
from ..Classes.Onderdeel.Luidspreker import Luidspreker
from ..Classes.Onderdeel.MACQPUFrontend import MACQPUFrontend
from ..Classes.Onderdeel.MIVCommunicatiekaart import MIVCommunicatiekaart
from ..Classes.Onderdeel.MIVLus import MIVLus
from ..Classes.Onderdeel.MIVLuskaart import MIVLuskaart
from ..Classes.Onderdeel.MIVProcessorkaart import MIVProcessorkaart
from ..Classes.Onderdeel.MIVVoedingsmodule import MIVVoedingsmodule
from ..Classes.Onderdeel.Magneetgrendel import Magneetgrendel
from ..Classes.Onderdeel.Mantelbuis import Mantelbuis
from ..Classes.Onderdeel.Meetcel import Meetcel
from ..Classes.Onderdeel.Meetmicrofoon import Meetmicrofoon
from ..Classes.Onderdeel.Metselwerk import Metselwerk
from ..Classes.Onderdeel.Micropaal import Micropaal
from ..Classes.Onderdeel.Montagekast import Montagekast
from ..Classes.Onderdeel.Motorbeveiligingsschakelaar import Motorbeveiligingsschakelaar
from ..Classes.Onderdeel.Motorsturing import Motorsturing
from ..Classes.Onderdeel.Motorvangplank import Motorvangplank
from ..Classes.Onderdeel.Muurdoorgangsstuk import Muurdoorgangsstuk
from ..Classes.Onderdeel.Muurvegetatie import Muurvegetatie
from ..Classes.Onderdeel.Naaf import Naaf
from ..Classes.Onderdeel.Naaldhout import Naaldhout
from ..Classes.Onderdeel.NatteRuigte import NatteRuigte
from ..Classes.Onderdeel.Neerslagsensor import Neerslagsensor
from ..Classes.Onderdeel.Netstabilisator import Netstabilisator
from ..Classes.Onderdeel.NetwerkModem import NetwerkModem
from ..Classes.Onderdeel.Netwerkelement import Netwerkelement
from ..Classes.Onderdeel.Netwerkkaart import Netwerkkaart
from ..Classes.Onderdeel.Netwerkpoort import Netwerkpoort
from ..Classes.Onderdeel.NietConformBegin import NietConformBegin
from ..Classes.Onderdeel.NietGetestBeginstuk import NietGetestBeginstuk
from ..Classes.Onderdeel.NietSelectieveDetectielus import NietSelectieveDetectielus
from ..Classes.Onderdeel.NietStandaardStalenProfiel import NietStandaardStalenProfiel
from ..Classes.Onderdeel.Noodstopknop import Noodstopknop
from ..Classes.Onderdeel.Noodverlichtingstoestel import Noodverlichtingstoestel
from ..Classes.Onderdeel.Noppendrainage import Noppendrainage
from ..Classes.Onderdeel.Obstakelbeveiliger import Obstakelbeveiliger
from ..Classes.Onderdeel.OmegaElement import OmegaElement
from ..Classes.Onderdeel.Omhult import Omhult
from ..Classes.Onderdeel.Omvormer import Omvormer
from ..Classes.Onderdeel.OnbegroeidVoorkomen import OnbegroeidVoorkomen
from ..Classes.Onderdeel.Onderbouw import Onderbouw
from ..Classes.Onderdeel.Onderdoorboring import Onderdoorboring
from ..Classes.Onderdeel.Onderdrukventilator import Onderdrukventilator
from ..Classes.Onderdeel.Onderstel import Onderstel
from ..Classes.Onderdeel.Onderwaterkruising import Onderwaterkruising
from ..Classes.Onderdeel.Onderwatervegetatie import Onderwatervegetatie
from ..Classes.Onderdeel.OntluchterBrandleiding import OntluchterBrandleiding
from ..Classes.Onderdeel.Ontluchtingsventiel import Ontluchtingsventiel
from ..Classes.Onderdeel.Ontvanger import Ontvanger
from ..Classes.Onderdeel.OpenInfiltratievoorziening import OpenInfiltratievoorziening
from ..Classes.Onderdeel.OpenbaarVervoerslantaarn import OpenbaarVervoerslantaarn
from ..Classes.Onderdeel.OpgaandeBoom import OpgaandeBoom
from ..Classes.Onderdeel.OpgaandeHoutigeVegetatie import OpgaandeHoutigeVegetatie
from ..Classes.Onderdeel.Oplegging import Oplegging
from ..Classes.Onderdeel.OptischeWegdeksensor import OptischeWegdeksensor
from ..Classes.Onderdeel.Overdrukventilator import Overdrukventilator
from ..Classes.Onderdeel.Overgangsconstructie import Overgangsconstructie
from ..Classes.Onderdeel.OverlangseMarkering import OverlangseMarkering
from ..Classes.Onderdeel.Overstort import Overstort
from ..Classes.Onderdeel.Overstortrand import Overstortrand
from ..Classes.Onderdeel.PCIKaart import PCIKaart
from ..Classes.Onderdeel.PLC import PLC
from ..Classes.Onderdeel.PMU import PMU
from ..Classes.Onderdeel.PTDemodulatoren import PTDemodulatoren
from ..Classes.Onderdeel.PTKARModem import PTKARModem
from ..Classes.Onderdeel.PTModem import PTModem
from ..Classes.Onderdeel.PTRadio import PTRadio
from ..Classes.Onderdeel.PTRegelaar import PTRegelaar
from ..Classes.Onderdeel.PTSCKaart import PTSCKaart
from ..Classes.Onderdeel.PTUitgangskaart import PTUitgangskaart
from ..Classes.Onderdeel.PTVerwerkingseenheid import PTVerwerkingseenheid
from ..Classes.Onderdeel.PTVoedingsmodule import PTVoedingsmodule
from ..Classes.Onderdeel.Pen import Pen
from ..Classes.Onderdeel.Pendel import Pendel
from ..Classes.Onderdeel.Persleiding import Persleiding
from ..Classes.Onderdeel.Pictogram import Pictogram
from ..Classes.Onderdeel.PiezometrischeBuis import PiezometrischeBuis
from ..Classes.Onderdeel.Plantbakvorm import Plantbakvorm
from ..Classes.Onderdeel.PlintGC import PlintGC
from ..Classes.Onderdeel.Plooibaken import Plooibaken
from ..Classes.Onderdeel.PoEInjector import PoEInjector
from ..Classes.Onderdeel.Pomp import Pomp
from ..Classes.Onderdeel.Pompgeleiding import Pompgeleiding
from ..Classes.Onderdeel.Pomphuis import Pomphuis
from ..Classes.Onderdeel.Portiek import Portiek
from ..Classes.Onderdeel.Printer import Printer
from ..Classes.Onderdeel.PunctueleVerlichtingsmast import PunctueleVerlichtingsmast
from ..Classes.Onderdeel.PutBovenbouw import PutBovenbouw
from ..Classes.Onderdeel.Putbekleding import Putbekleding
from ..Classes.Onderdeel.Pyranometer import Pyranometer
from ..Classes.Onderdeel.RIS import RIS
from ..Classes.Onderdeel.RaaigrasweideGraslandfase0 import RaaigrasweideGraslandfase0
from ..Classes.Onderdeel.Rack import Rack
from ..Classes.Onderdeel.Radar import Radar
from ..Classes.Onderdeel.RadarNiveaumeting import RadarNiveaumeting
from ..Classes.Onderdeel.Radiolistener import Radiolistener
from ..Classes.Onderdeel.Railconstructie import Railconstructie
from ..Classes.Onderdeel.RechteSteun import RechteSteun
from ..Classes.Onderdeel.Referentiepunt import Referentiepunt
from ..Classes.Onderdeel.ReflectorInLijnvormigElement import ReflectorInLijnvormigElement
from ..Classes.Onderdeel.Reflectorpaal import Reflectorpaal
from ..Classes.Onderdeel.RegelbaarTegengewicht import RegelbaarTegengewicht
from ..Classes.Onderdeel.Relais import Relais
from ..Classes.Onderdeel.Repeater import Repeater
from ..Classes.Onderdeel.Reservoir import Reservoir
from ..Classes.Onderdeel.RetroReflecterendeKoker import RetroReflecterendeKoker
from ..Classes.Onderdeel.RetroreflecterendVerkeersbord import RetroreflecterendVerkeersbord
from ..Classes.Onderdeel.RetroreflecterendeFolie import RetroreflecterendeFolie
from ..Classes.Onderdeel.Riem import Riem
from ..Classes.Onderdeel.Riemschijf import Riemschijf
from ..Classes.Onderdeel.Riemspanner import Riemspanner
from ..Classes.Onderdeel.Riet import Riet
from ..Classes.Onderdeel.RingMechanisch import RingMechanisch
from ..Classes.Onderdeel.Rioleringsbuis import Rioleringsbuis
from ..Classes.Onderdeel.Riooltoegang import Riooltoegang
from ..Classes.Onderdeel.Rol import Rol
from ..Classes.Onderdeel.Rolwagenchassis import Rolwagenchassis
from ..Classes.Onderdeel.Ruigte import Ruigte
from ..Classes.Onderdeel.Schacht import Schacht
from ..Classes.Onderdeel.Schakel import Schakel
from ..Classes.Onderdeel.Schakelketting import Schakelketting
from ..Classes.Onderdeel.SchampkantAfw import SchampkantAfw
from ..Classes.Onderdeel.SchampkantStd import SchampkantStd
from ..Classes.Onderdeel.Schanskorf import Schanskorf
from ..Classes.Onderdeel.ScheurremmendeLaag import ScheurremmendeLaag
from ..Classes.Onderdeel.Schommeljuk import Schommeljuk
from ..Classes.Onderdeel.Segmentcontroller import Segmentcontroller
from ..Classes.Onderdeel.Seinbord import Seinbord
from ..Classes.Onderdeel.Seinbrug import Seinbrug
from ..Classes.Onderdeel.SelectieveDetectielus import SelectieveDetectielus
from ..Classes.Onderdeel.Sierbeplanting import Sierbeplanting
from ..Classes.Onderdeel.SignaalControleModule import SignaalControleModule
from ..Classes.Onderdeel.SignaalSplitter import SignaalSplitter
from ..Classes.Onderdeel.Signaalfilter import Signaalfilter
from ..Classes.Onderdeel.Signaalkabel import Signaalkabel
from ..Classes.Onderdeel.Silo import Silo
from ..Classes.Onderdeel.Slagboomarm import Slagboomarm
from ..Classes.Onderdeel.SlagboomarmVerlichting import SlagboomarmVerlichting
from ..Classes.Onderdeel.Slagboomkolom import Slagboomkolom
from ..Classes.Onderdeel.Slemlaag import Slemlaag
from ..Classes.Onderdeel.Sleuf import Sleuf
from ..Classes.Onderdeel.Sleufbekisting import Sleufbekisting
from ..Classes.Onderdeel.Slot import Slot
from ..Classes.Onderdeel.Slotcilinder import Slotcilinder
from ..Classes.Onderdeel.Sluisvloertegel import Sluisvloertegel
from ..Classes.Onderdeel.SluitAanOp import SluitAanOp
from ..Classes.Onderdeel.Smeernippel import Smeernippel
from ..Classes.Onderdeel.Software import Software
from ..Classes.Onderdeel.SoilmixwandElement import SoilmixwandElement
from ..Classes.Onderdeel.Sokkel import Sokkel
from ..Classes.Onderdeel.SolitaireHeester import SolitaireHeester
from ..Classes.Onderdeel.SoortenrijkSchraalGraslandGraslandfase5 import SoortenrijkSchraalGraslandGraslandfase5
from ..Classes.Onderdeel.Spaarbekken import Spaarbekken
from ..Classes.Onderdeel.Spankabel import Spankabel
from ..Classes.Onderdeel.Spanningsomvormer import Spanningsomvormer
from ..Classes.Onderdeel.Spanstaaf import Spanstaaf
from ..Classes.Onderdeel.Spindel import Spindel
from ..Classes.Onderdeel.Spindelmoer import Spindelmoer
from ..Classes.Onderdeel.Spuitbeton import Spuitbeton
from ..Classes.Onderdeel.Staalkabel import Staalkabel
from ..Classes.Onderdeel.StalenBuispaal import StalenBuispaal
from ..Classes.Onderdeel.StalenConstructieObject import StalenConstructieObject
from ..Classes.Onderdeel.StalenDamplank import StalenDamplank
from ..Classes.Onderdeel.StalenPlaat import StalenPlaat
from ..Classes.Onderdeel.StalenSchroefpaal import StalenSchroefpaal
from ..Classes.Onderdeel.StalenTrekstaaf import StalenTrekstaaf
from ..Classes.Onderdeel.StandaardStalenProfiel import StandaardStalenProfiel
from ..Classes.Onderdeel.Stang import Stang
from ..Classes.Onderdeel.Steenslagverharding import Steenslagverharding
from ..Classes.Onderdeel.Stobbenwal import Stobbenwal
from ..Classes.Onderdeel.Stootblok import Stootblok
from ..Classes.Onderdeel.Stopcontact import Stopcontact
from ..Classes.Onderdeel.Stormraam import Stormraam
from ..Classes.Onderdeel.Stortdraad import Stortdraad
from ..Classes.Onderdeel.Stortsteen import Stortsteen
from ..Classes.Onderdeel.Stortsteenpenetratie import Stortsteenpenetratie
from ..Classes.Onderdeel.Straatkap import Straatkap
from ..Classes.Onderdeel.Straatkolk import Straatkolk
from ..Classes.Onderdeel.StralendeKabel import StralendeKabel
from ..Classes.Onderdeel.StroomMeetmodule import StroomMeetmodule
from ..Classes.Onderdeel.Stroomdalgrasland import Stroomdalgrasland
from ..Classes.Onderdeel.Stroomkring import Stroomkring
from ..Classes.Onderdeel.Stroomverdelingssysteem import Stroomverdelingssysteem
from ..Classes.Onderdeel.Struweel import Struweel
from ..Classes.Onderdeel.Sturing import Sturing
from ..Classes.Onderdeel.Stuurklep import Stuurklep
from ..Classes.Onderdeel.StuurklepBrandleiding import StuurklepBrandleiding
from ..Classes.Onderdeel.Stuwconstructie import Stuwconstructie
from ..Classes.Onderdeel.TGCUitbreidingsModule import TGCUitbreidingsModule
from ..Classes.Onderdeel.TLCfiPoort import TLCfiPoort
from ..Classes.Onderdeel.Taatspen import Taatspen
from ..Classes.Onderdeel.Taatspot import Taatspot
from ..Classes.Onderdeel.Taatsschoen import Taatsschoen
from ..Classes.Onderdeel.Taludgoot import Taludgoot
from ..Classes.Onderdeel.Tandheugel import Tandheugel
from ..Classes.Onderdeel.Tandkrans import Tandkrans
from ..Classes.Onderdeel.Tandwiel import Tandwiel
from ..Classes.Onderdeel.Tandwielkast import Tandwielkast
from ..Classes.Onderdeel.Tank import Tank
from ..Classes.Onderdeel.TechnischePut import TechnischePut
from ..Classes.Onderdeel.Tegenmateriaal import Tegenmateriaal
from ..Classes.Onderdeel.Telecomkabel import Telecomkabel
from ..Classes.Onderdeel.Temperatuursensor import Temperatuursensor
from ..Classes.Onderdeel.Ternairmengselverharding import Ternairmengselverharding
from ..Classes.Onderdeel.Terugkeer import Terugkeer
from ..Classes.Onderdeel.Terugslagklep import Terugslagklep
from ..Classes.Onderdeel.ThermoHygrometer import ThermoHygrometer
from ..Classes.Onderdeel.Tijdschakelaar import Tijdschakelaar
from ..Classes.Onderdeel.Toegangscontrole import Toegangscontrole
from ..Classes.Onderdeel.Toegangscontroller import Toegangscontroller
from ..Classes.Onderdeel.Toegangsluik import Toegangsluik
from ..Classes.Onderdeel.Toegangspoort import Toegangspoort
from ..Classes.Onderdeel.Toegangsvoorziening import Toegangsvoorziening
from ..Classes.Onderdeel.Toestelventilator import Toestelventilator
from ..Classes.Onderdeel.Transformator import Transformator
from ..Classes.Onderdeel.Trap import Trap
from ..Classes.Onderdeel.TrekdraadEncoderNiveaumeting import TrekdraadEncoderNiveaumeting
from ..Classes.Onderdeel.Trillingsvoorziening import Trillingsvoorziening
from ..Classes.Onderdeel.TrottoirbandAfw import TrottoirbandAfw
from ..Classes.Onderdeel.TrottoirbandStd import TrottoirbandStd
from ..Classes.Onderdeel.TrottoirbandWatergreppelAfw import TrottoirbandWatergreppelAfw
from ..Classes.Onderdeel.TrottoirbandWatergreppelStd import TrottoirbandWatergreppelStd
from ..Classes.Onderdeel.UPS import UPS
from ..Classes.Onderdeel.UitheemsLoofhout import UitheemsLoofhout
from ..Classes.Onderdeel.UltrasoonNiveaumeting import UltrasoonNiveaumeting
from ..Classes.Onderdeel.VRBAZ import VRBAZ
from ..Classes.Onderdeel.VRBatterijICU import VRBatterijICU
from ..Classes.Onderdeel.VRBeveiligingskaart import VRBeveiligingskaart
from ..Classes.Onderdeel.VRCommunicatiekaart import VRCommunicatiekaart
from ..Classes.Onderdeel.VRHandbediening import VRHandbediening
from ..Classes.Onderdeel.VRIVirtueleDetectiezone import VRIVirtueleDetectiezone
from ..Classes.Onderdeel.VRIngangscontacten import VRIngangscontacten
from ..Classes.Onderdeel.VRKortsluitbeveiliging import VRKortsluitbeveiliging
from ..Classes.Onderdeel.VRLuskaart import VRLuskaart
from ..Classes.Onderdeel.VRStuurkaart import VRStuurkaart
from ..Classes.Onderdeel.VRUitgangscontacten import VRUitgangscontacten
from ..Classes.Onderdeel.VastTegengewicht import VastTegengewicht
from ..Classes.Onderdeel.Veerhuis import Veerhuis
from ..Classes.Onderdeel.Veerooster import Veerooster
from ..Classes.Onderdeel.Veiligheidsrelais import Veiligheidsrelais
from ..Classes.Onderdeel.VentilatieAfsluitklep import VentilatieAfsluitklep
from ..Classes.Onderdeel.Ventilatierooster import Ventilatierooster
from ..Classes.Onderdeel.Ventilator import Ventilator
from ..Classes.Onderdeel.Verankeringslandhoofd import Verankeringslandhoofd
from ..Classes.Onderdeel.Verankeringsmassief import Verankeringsmassief
from ..Classes.Onderdeel.VerankeringsplaatMicropaal import VerankeringsplaatMicropaal
from ..Classes.Onderdeel.Verenpakket import Verenpakket
from ..Classes.Onderdeel.VerhardingGrasKunststofplaat import VerhardingGrasKunststofplaat
from ..Classes.Onderdeel.Verkeersbordsteun import Verkeersbordsteun
from ..Classes.Onderdeel.VerkeerslichtGroen import VerkeerslichtGroen
from ..Classes.Onderdeel.VerkeerslichtOranjegeel import VerkeerslichtOranjegeel
from ..Classes.Onderdeel.VerkeerslichtRood import VerkeerslichtRood
from ..Classes.Onderdeel.VerkeerslichtWit import VerkeerslichtWit
from ..Classes.Onderdeel.Verkeersregelaar import Verkeersregelaar
from ..Classes.Onderdeel.Verkeersspiegel import Verkeersspiegel
from ..Classes.Onderdeel.Verkenmerk import Verkenmerk
from ..Classes.Onderdeel.VerlichtingstoestelHgLP import VerlichtingstoestelHgLP
from ..Classes.Onderdeel.VerlichtingstoestelLED import VerlichtingstoestelLED
from ..Classes.Onderdeel.VerlichtingstoestelMHHP import VerlichtingstoestelMHHP
from ..Classes.Onderdeel.VerlichtingstoestelNaHP import VerlichtingstoestelNaHP
from ..Classes.Onderdeel.VerlichtingstoestelNaLP import VerlichtingstoestelNaLP
from ..Classes.Onderdeel.VerlichtingstoestelTL import VerlichtingstoestelTL
from ..Classes.Onderdeel.Verluchtingskap import Verluchtingskap
from ..Classes.Onderdeel.VerruigdGrasland import VerruigdGrasland
from ..Classes.Onderdeel.VerstoordGrasland import VerstoordGrasland
from ..Classes.Onderdeel.Verwarmingselement import Verwarmingselement
from ..Classes.Onderdeel.Verwarmingslint import Verwarmingslint
from ..Classes.Onderdeel.VirtueleServer import VirtueleServer
from ..Classes.Onderdeel.VlakGeluidsschermelement import VlakGeluidsschermelement
from ..Classes.Onderdeel.Vlierstruweel import Vlierstruweel
from ..Classes.Onderdeel.Vlotplaat import Vlotplaat
from ..Classes.Onderdeel.VlottendeBolder import VlottendeBolder
from ..Classes.Onderdeel.Vlotterschakelaar import Vlotterschakelaar
from ..Classes.Onderdeel.Vluchtdeur import Vluchtdeur
from ..Classes.Onderdeel.Vluchtopening import Vluchtopening
from ..Classes.Onderdeel.VoedingDerdenLaagspanning import VoedingDerdenLaagspanning
from ..Classes.Onderdeel.Voedingskabel import Voedingskabel
from ..Classes.Onderdeel.Voedingskeuzeschakelaar import Voedingskeuzeschakelaar
from ..Classes.Onderdeel.Voedt import Voedt
from ..Classes.Onderdeel.VoedtAangestuurd import VoedtAangestuurd
from ..Classes.Onderdeel.Voegband import Voegband
from ..Classes.Onderdeel.Voegplaat import Voegplaat
from ..Classes.Onderdeel.VoertuigkerendGeluidsschermelement import VoertuigkerendGeluidsschermelement
from ..Classes.Onderdeel.Voertuiglantaarn import Voertuiglantaarn
from ..Classes.Onderdeel.Voetbocht import Voetbocht
from ..Classes.Onderdeel.Voetgangerslantaarn import Voetgangerslantaarn
from ..Classes.Onderdeel.Vooraankondiging import Vooraankondiging
from ..Classes.Onderdeel.Voorschakelapparaat import Voorschakelapparaat
from ..Classes.Onderdeel.Voorzetconstructie import Voorzetconstructie
from ..Classes.Onderdeel.VulpuntBrandweer import VulpuntBrandweer
from ..Classes.Onderdeel.WIMDatalogger import WIMDatalogger
from ..Classes.Onderdeel.WVConsole import WVConsole
from ..Classes.Onderdeel.WVLichtmast import WVLichtmast
from ..Classes.Onderdeel.WVOpvoertransformator import WVOpvoertransformator
from ..Classes.Onderdeel.Waaier import Waaier
from ..Classes.Onderdeel.Walsbetonverharding import Walsbetonverharding
from ..Classes.Onderdeel.WaterdoorlatendeBestrating import WaterdoorlatendeBestrating
from ..Classes.Onderdeel.WatergreppelAfw import WatergreppelAfw
from ..Classes.Onderdeel.WatergreppelStd import WatergreppelStd
from ..Classes.Onderdeel.Waterloop import Waterloop
from ..Classes.Onderdeel.WazeBeacon import WazeBeacon
from ..Classes.Onderdeel.Weegcel import Weegcel
from ..Classes.Onderdeel.Weegcomputer import Weegcomputer
from ..Classes.Onderdeel.Weegplaat import Weegplaat
from ..Classes.Onderdeel.Weegsensor import Weegsensor
from ..Classes.Onderdeel.WegbebakeningAfschermendeConstructies import WegbebakeningAfschermendeConstructies
from ..Classes.Onderdeel.Wegdeksensor import Wegdeksensor
from ..Classes.Onderdeel.Wegdekvoeg import Wegdekvoeg
from ..Classes.Onderdeel.WeggebondenDetector import WeggebondenDetector
from ..Classes.Onderdeel.Wegkantkast import Wegkantkast
from ..Classes.Onderdeel.Wegreflector import Wegreflector
from ..Classes.Onderdeel.Wentellager import Wentellager
from ..Classes.Onderdeel.Werkschakelaar import Werkschakelaar
from ..Classes.Onderdeel.Werkvloer import Werkvloer
from ..Classes.Onderdeel.Wervel import Wervel
from ..Classes.Onderdeel.Wiel import Wiel
from ..Classes.Onderdeel.Wiepenmat import Wiepenmat
from ..Classes.Onderdeel.Wildreflector import Wildreflector
from ..Classes.Onderdeel.Wilgenstruweel import Wilgenstruweel
from ..Classes.Onderdeel.Windmeter import Windmeter
from ..Classes.Onderdeel.Wormschroef import Wormschroef
from ..Classes.Onderdeel.Zelfsluiter import Zelfsluiter
from ..Classes.Onderdeel.Zender import Zender
from ..Classes.Onderdeel.Zendmast import Zendmast
from ..Classes.Onderdeel.Zendontvanger import Zendontvanger
from ..Classes.Onderdeel.Zonnepaneel import Zonnepaneel
from ..Classes.Onderdeel.ZuilTGC import ZuilTGC
from ..Classes.ProefEnMeting.Keuring import Keuring
from ..Classes.ProefEnMeting.MeteropnameEnergiemeter import MeteropnameEnergiemeter
from ..Classes.ProefEnMeting.MeteropnameEnergiemeterGecombineerd import MeteropnameEnergiemeterGecombineerd
from ..Classes.ProefEnMeting.ProefBindmiddeldosering import ProefBindmiddeldosering
from ..Classes.ProefEnMeting.ProefBoomtoestand import ProefBoomtoestand
from ..Classes.ProefEnMeting.ProefConsistentie import ProefConsistentie
from ..Classes.ProefEnMeting.ProefDoorlatendheid import ProefDoorlatendheid
from ..Classes.ProefEnMeting.ProefDraagvermogen import ProefDraagvermogen
from ..Classes.ProefEnMeting.ProefDraineervermogen import ProefDraineervermogen
from ..Classes.ProefEnMeting.ProefDruksterkte import ProefDruksterkte
from ..Classes.ProefEnMeting.ProefDwarsvlakheid import ProefDwarsvlakheid
from ..Classes.ProefEnMeting.ProefEffectiefBindmiddelgehalte import ProefEffectiefBindmiddelgehalte
from ..Classes.ProefEnMeting.ProefGaafheid import ProefGaafheid
from ..Classes.ProefEnMeting.ProefGeluidstest import ProefGeluidstest
from ..Classes.ProefEnMeting.ProefGemetenDikte import ProefGemetenDikte
from ..Classes.ProefEnMeting.ProefGrondkarakteristieken import ProefGrondkarakteristieken
from ..Classes.ProefEnMeting.ProefHechtsterkte import ProefHechtsterkte
from ..Classes.ProefEnMeting.ProefKerendVermogen import ProefKerendVermogen
from ..Classes.ProefEnMeting.ProefKorrelverdeling import ProefKorrelverdeling
from ..Classes.ProefEnMeting.ProefLangsvlakheid import ProefLangsvlakheid
from ..Classes.ProefEnMeting.ProefLuchtdichtheid import ProefLuchtdichtheid
from ..Classes.ProefEnMeting.ProefLuchtgehalte import ProefLuchtgehalte
from ..Classes.ProefEnMeting.ProefLuminantie import ProefLuminantie
from ..Classes.ProefEnMeting.ProefMortelkwaliteit import ProefMortelkwaliteit
from ..Classes.ProefEnMeting.ProefNaderOnderzoekTomograaf import ProefNaderOnderzoekTomograaf
from ..Classes.ProefEnMeting.ProefPctHolleruimte import ProefPctHolleruimte
from ..Classes.ProefEnMeting.ProefPerformantieklasse import ProefPerformantieklasse
from ..Classes.ProefEnMeting.ProefPerformantieniveau import ProefPerformantieniveau
from ..Classes.ProefEnMeting.ProefRetroreflectie import ProefRetroreflectie
from ..Classes.ProefEnMeting.ProefRolgeluid import ProefRolgeluid
from ..Classes.ProefEnMeting.ProefSchokindex import ProefSchokindex
from ..Classes.ProefEnMeting.ProefSchokindexMVP import ProefSchokindexMVP
from ..Classes.ProefEnMeting.ProefStaalvezelgehalte import ProefStaalvezelgehalte
from ..Classes.ProefEnMeting.ProefStroefheid import ProefStroefheid
from ..Classes.ProefEnMeting.ProefTemperatuur import ProefTemperatuur
from ..Classes.ProefEnMeting.ProefTextuurdiepte import ProefTextuurdiepte
from ..Classes.ProefEnMeting.ProefVerankeringskracht import ProefVerankeringskracht
from ..Classes.ProefEnMeting.ProefVerderOnderzoekTrekproef import ProefVerderOnderzoekTrekproef
from ..Classes.ProefEnMeting.ProefVisueleBeoordeling import ProefVisueleBeoordeling
from ..Classes.ProefEnMeting.ProefVlakheid import ProefVlakheid
from ..Classes.ProefEnMeting.ProefVoertuigOverhelling import ProefVoertuigOverhelling
from ..Classes.ProefEnMeting.ProefWaterdichtheid import ProefWaterdichtheid
from ..Classes.ProefEnMeting.ProefWatergehalte import ProefWatergehalte
from ..Classes.ProefEnMeting.ProefWateropslorping import ProefWateropslorping
from ..Classes.ProefEnMeting.ProefWeerstandAfschilfering import ProefWeerstandAfschilfering
from ..Classes.ProefEnMeting.ProefWerkingsbreedteGC import ProefWerkingsbreedteGC
from ..Classes.ProefEnMeting.ProefWerkingsbreedteMVP import ProefWerkingsbreedteMVP
from ..Classes.ProefEnMeting.ProefZichtbaarheidBijDagOfWV import ProefZichtbaarheidBijDagOfWV
from ..Classes.ProefEnMeting.ProefZichtbaarheidBijNacht import ProefZichtbaarheidBijNacht
from ..Classes.ProefEnMeting.ProefZichtbaarheidBijNachtNatWegdek import ProefZichtbaarheidBijNachtNatWegdek
from ..Classes.ProefEnMeting.ProefZichtbaarheidBijNachtRegenweer import ProefZichtbaarheidBijNachtRegenweer
from ..Classes.Legacy.IRVerlichter import IRVerlichter
from ..Classes.Legacy.VKS import VKS
from ..Classes.Legacy.Z30Controller import Z30Controller
from ..Classes.Legacy.CaDoGroep import CaDoGroep
from ..Classes.Legacy.LWP import LWP
from ..Classes.Legacy.HY_CI import HY_CI
from ..Classes.Legacy.HY_GR import HY_GR
from ..Classes.Legacy.Poortbedieningen import Poortbedieningen
from ..Classes.Legacy.MotorLegacy import MotorLegacy
from ..Classes.Legacy.StuurklepLeiding import StuurklepLeiding
from ..Classes.Legacy.FlexibeleBuis import FlexibeleBuis
from ..Classes.Legacy.ZoutBijlaadPlaats import ZoutBijlaadPlaats
from ..Classes.Legacy.ITSApp_RIS import ITSApp_RIS
from ..Classes.Legacy.Zoutsilo import Zoutsilo
from ..Classes.Legacy.Pekeltank import Pekeltank
from ..Classes.Legacy.BelInstallatie import BelInstallatie
from ..Classes.Legacy.RIOOL import RIOOL
from ..Classes.Legacy.LokaalLegacy import LokaalLegacy
from ..Classes.Legacy.Dienstdeur import Dienstdeur
from ..Classes.Legacy.FietsTelDisplayLegacy import FietsTelDisplayLegacy
from ..Classes.Legacy.FietsTelSysteemLegacy import FietsTelSysteemLegacy
from ..Classes.Legacy.DPBS import DPBS
from ..Classes.Legacy.DPBSOnd import DPBSOnd
from ..Classes.Legacy.WegDetectorLegacy import WegDetectorLegacy
from ..Classes.Legacy.SegC import SegC
from ..Classes.Legacy.Netwerktoegang import Netwerktoegang
from ..Classes.Legacy.Turbine import Turbine
from ..Classes.Legacy.WeegsensorLegacy import WeegsensorLegacy
from ..Classes.Legacy.WeegsensorGroep import WeegsensorGroep
from ..Classes.Legacy.Luchtkwaliteitssensor import Luchtkwaliteitssensor
from ..Classes.Legacy.Beacon import Beacon
from ..Classes.Legacy.Leidingkoker import Leidingkoker
from ..Classes.Legacy.SeinBak import SeinBak
from ..Classes.Legacy.SeinSpui import SeinSpui
from ..Classes.Legacy.RLCGUI import RLCGUI
from ..Classes.Legacy.SlbGroep import SlbGroep
from ..Classes.Legacy.Calam import Calam
from ..Classes.Legacy.Glad import Glad
from ..Classes.Legacy.Ijking import Ijking
from ..Classes.Legacy.VOTLus import VOTLus
from ..Classes.Legacy.VVOPGroep import VVOPGroep
from ..Classes.Legacy.Brandvoorz import Brandvoorz
from ..Classes.Legacy.RRGroep import RRGroep
from ..Classes.Legacy.AntenneI2V import AntenneI2V
from ..Classes.Legacy.Monitor import Monitor
from ..Classes.Legacy.LuiLegacy import LuiLegacy
from ..Classes.Legacy.NIC import NIC
from ..Classes.Legacy.Winter import Winter
from ..Classes.Legacy.Z30Paal import Z30Paal
from ..Classes.Legacy.Z30 import Z30
from ..Classes.Legacy.Pluvio import Pluvio
from ..Classes.Legacy.ARS import ARS
from ..Classes.Legacy.RHZ import RHZ
from ..Classes.Legacy.Picto import Picto
from ..Classes.Legacy.Nooddeur import Nooddeur
from ..Classes.Legacy.KeuringLegacy import KeuringLegacy
from ..Classes.Legacy.Deb import Deb
from ..Classes.Legacy.MON import MON
from ..Classes.Legacy.Kwik import Kwik
from ..Classes.Legacy.Div import Div
from ..Classes.Legacy.Peil import Peil
from ..Classes.Legacy.Lev import Lev
from ..Classes.Legacy.Cal import Cal
from ..Classes.Legacy.Sensor import Sensor
from ..Classes.Legacy.GebUitr import GebUitr
from ..Classes.Legacy.GebouwLegacy import GebouwLegacy
from ..Classes.Legacy.ServerGrp import ServerGrp
from ..Classes.Legacy.Server import Server
from ..Classes.Legacy.IVSBGroep import IVSBGroep
from ..Classes.Legacy.SeinbrugIVS import SeinbrugIVS
from ..Classes.Legacy.MDeC import MDeC
from ..Classes.Legacy.Kast import Kast
from ..Classes.Legacy.Wilddet import Wilddet
from ..Classes.Legacy.Terrein import Terrein
from ..Classes.Legacy.Druk import Druk
from ..Classes.Legacy.Wind import Wind
from ..Classes.Legacy.VPBevestig import VPBevestig
from ..Classes.Legacy.VPConsole import VPConsole
from ..Classes.Legacy.KAR import KAR
from ..Classes.Legacy.RRB import RRB
from ..Classes.Legacy.RISLegacy import RISLegacy
from ..Classes.Legacy.Tekstkar import Tekstkar
from ..Classes.Legacy.SoftwareLegacy import SoftwareLegacy
from ..Classes.Legacy.MobADR import MobADR
from ..Classes.Legacy.IP import IP
from ..Classes.Legacy.TWeg import TWeg
from ..Classes.Legacy.VSB import VSB
from ..Classes.Legacy.AWeg import AWeg
from ..Classes.Legacy.NWeg import NWeg
from ..Classes.Legacy.BWeg import BWeg
from ..Classes.Legacy.RWeg import RWeg
from ..Classes.Legacy.VOT import VOT
from ..Classes.Legacy.Instal import Instal
from ..Classes.Legacy.RTU import RTU
from ..Classes.Legacy.Kan import Kan
from ..Classes.Legacy.Com import Com
from ..Classes.Legacy.TTN3 import TTN3
from ..Classes.Legacy.TTN2 import TTN2
from ..Classes.Legacy.TTN1 import TTN1
from ..Classes.Legacy.Dummy import Dummy
from ..Classes.Legacy.TraCoLegacy import TraCoLegacy
from ..Classes.Legacy.WIM import WIM
from ..Classes.Legacy.CBBS import CBBS
from ..Classes.Legacy.VWS import VWS
from ..Classes.Legacy.TGB import TGB
from ..Classes.Legacy.WKD import WKD
from ..Classes.Legacy.BAf import BAf
from ..Classes.Legacy.MVE import MVE
from ..Classes.Legacy.ICU import ICU
from ..Classes.Legacy.VDP import VDP
from ..Classes.Legacy.Veer import Veer
from ..Classes.Legacy.WV import WV
from ..Classes.Legacy.WDM import WDM
from ..Classes.Legacy.WBr import WBr
from ..Classes.Legacy.VVOP import VVOP
from ..Classes.Legacy.VRLegacy import VRLegacy
from ..Classes.Legacy.VL import VL
from ..Classes.Legacy.VGL import VGL
from ..Classes.Legacy.UPSLegacy import UPSLegacy
from ..Classes.Legacy.TuV import TuV
from ..Classes.Legacy.Tu import Tu
from ..Classes.Legacy.TTN import TTN
from ..Classes.Legacy.TT import TT
from ..Classes.Legacy.TGC import TGC
from ..Classes.Legacy.Tel import Tel
from ..Classes.Legacy.TCC import TCC
from ..Classes.Legacy.Str import Str
from ..Classes.Legacy.Stuw import Stuw
from ..Classes.Legacy.Ssig import Ssig
from ..Classes.Legacy.Sluis import Sluis
from ..Classes.Legacy.SDH import SDH
from ..Classes.Legacy.Schuiven import Schuiven
from ..Classes.Legacy.Rooster import Rooster
from ..Classes.Legacy.Ramp import Ramp
from ..Classes.Legacy.Radio import Radio
from ..Classes.Legacy.PTK import PTK
from ..Classes.Legacy.PP import PP
from ..Classes.Legacy.PoS import PoS
from ..Classes.Legacy.NSG import NSG
from ..Classes.Legacy.ModRck import ModRck
from ..Classes.Legacy.Modem import Modem
from ..Classes.Legacy.MobDet import MobDet
from ..Classes.Legacy.Meteo import Meteo
from ..Classes.Legacy.LS import LS
from ..Classes.Legacy.Lift import Lift
from ..Classes.Legacy.KlimaLegacy import KlimaLegacy
from ..Classes.Legacy.Roltrap import Roltrap
from ..Classes.Legacy.Vent import Vent
from ..Classes.Legacy.KL import KL
from ..Classes.Legacy.IVSB import IVSB
from ..Classes.Legacy.Int import Int
from ..Classes.Legacy.HS import HS
from ..Classes.Legacy.HHW import HHW
from ..Classes.Legacy.FCel import FCel
from ..Classes.Legacy.Elc import Elc
from ..Classes.Legacy.Det import Det
from ..Classes.Legacy.CVL import CVL
from ..Classes.Legacy.Slb import Slb
from ..Classes.Legacy.CC import CC
from ..Classes.Legacy.BVE import BVE
from ..Classes.Legacy.Bus import Bus
from ..Classes.Legacy.BeweegbareBrug import BeweegbareBrug
from ..Classes.Legacy.BiF import BiF
from ..Classes.Legacy.BIB import BIB
from ..Classes.Legacy.BDV import BDV
from ..Classes.Legacy.BBT import BBT
from ..Classes.Legacy.ATOS import ATOS
from ..Classes.Legacy.Asw import Asw
from ..Classes.Legacy.Audio import Audio
from ..Classes.Legacy.AfGroep import AfGroep
from ..Classes.Legacy.Af import Af
from ..Classes.Legacy.AB import AB
from ..Classes.Legacy.COD import COD
from ..Classes.Legacy.PLCLegacy import PLCLegacy
from ..Classes.Legacy.Bareel import Bareel
from ..Classes.Legacy.BAFG import BAFG
from ..Classes.Legacy.Poortbediening import Poortbediening
from ..Classes.Legacy.VPLMast import VPLMast
from ..Classes.Legacy.Mpt import Mpt
from ..Classes.Legacy.HPGroep import HPGroep
from ..Classes.Legacy.CaDoLegacy import CaDoLegacy
from ..Classes.Legacy.Buitendeur import Buitendeur
from ..Classes.Legacy.Brandmelder import Brandmelder
from ..Classes.Legacy.ADRBuffer import ADRBuffer
from ..Classes.Legacy.VerbindD import VerbindD
from ..Classes.Legacy.BBLegacy import BBLegacy
from ..Classes.Legacy.HulppostLegacy import HulppostLegacy
from ..Classes.Legacy.Rookmelder import Rookmelder
from ..Classes.Legacy.Astrid import Astrid
from ..Classes.Legacy.BevRelais import BevRelais
from ..Classes.Legacy.DiffRelais import DiffRelais
from ..Classes.Legacy.HSMelder import HSMelder
from ..Classes.Legacy.OvRelais import OvRelais
from ..Classes.Legacy.LVS import LVS
from ..Classes.Legacy.LSBordLegacy import LSBordLegacy
from ..Classes.Legacy.NDVL import NDVL
from ..Classes.Legacy.PompLegacy import PompLegacy
from ..Classes.Legacy.Sstart import Sstart
from ..Classes.Legacy.Vlot import Vlot
from ..Classes.Legacy.SNCPaal import SNCPaal
from ..Classes.Legacy.RLCPaal import RLCPaal
from ..Classes.Legacy.Deurcontact import Deurcontact
from ..Classes.Legacy.ContourVLLegacy import ContourVLLegacy
from ..Classes.Legacy.Beton import Beton
from ..Classes.Legacy.HSDeel import HSDeel
from ..Classes.Legacy.LSDeel import LSDeel
from ..Classes.Legacy.HSCabineLegacy import HSCabineLegacy
from ..Classes.Legacy.OTN import OTN
from ..Classes.Legacy.CEN import CEN
from ..Classes.Legacy.Rijstrook import Rijstrook
from ..Classes.Legacy.Noodstroom import Noodstroom
from ..Classes.Legacy.Beheersys import Beheersys
from ..Classes.Legacy.VC import VC
from ..Classes.Legacy.ADW import ADW
from ..Classes.Legacy.SeinBaan import SeinBaan
from ..Classes.Legacy.SeinRiv import SeinRiv
from ..Classes.Legacy.SeinOnd import SeinOnd
from ..Classes.Legacy.SeinRicht import SeinRicht
from ..Classes.Legacy.SeinSch import SeinSch
from ..Classes.Legacy.SeinbrugRRB import SeinbrugRRB
from ..Classes.Legacy.OmvormerLegacy import OmvormerLegacy
from ..Classes.Legacy.Decoder import Decoder
from ..Classes.Legacy.ADR import ADR
from ..Classes.Legacy.FietstelLegacy import FietstelLegacy
from ..Classes.Legacy.MIVLVE import MIVLVE
from ..Classes.Legacy.CCTVPaal import CCTVPaal
from ..Classes.Legacy.TH import TH
from ..Classes.Legacy.Relais import Relais
from ..Classes.Legacy.MS import MS
from ..Classes.Legacy.Thermo import Thermo
from ..Classes.Legacy.TransfoLegacy import TransfoLegacy
from ..Classes.Legacy.HVS import HVS
from ..Classes.Legacy.Paal import Paal
from ..Classes.Legacy.SeinbrugRR import SeinbrugRR
from ..Classes.Legacy.PKGroep import PKGroep
from ..Classes.Legacy.PK import PK
from ..Classes.Legacy.RSSGroep import RSSGroep
from ..Classes.Legacy.VMSGroep import VMSGroep
from ..Classes.Legacy.RVMSGroep import RVMSGroep
from ..Classes.Legacy.RSSBord import RSSBord
from ..Classes.Legacy.RVMS import RVMS
from ..Classes.Legacy.RRBGroep import RRBGroep
from ..Classes.Legacy.WegPunt import WegPunt
from ..Classes.Legacy.HPicto import HPicto
from ..Classes.Legacy.Switch import Switch
from ..Classes.Legacy.CamGroep import CamGroep
from ..Classes.Legacy.SeinbrugDVM import SeinbrugDVM
from ..Classes.Legacy.MIVSat import MIVSat
from ..Classes.Legacy.PTZ import PTZ
from ..Classes.Legacy.ANPR import ANPR
from ..Classes.Legacy.CCTV import CCTV
from ..Classes.Legacy.AID import AID
from ..Classes.Legacy.Encoder import Encoder
from ..Classes.Legacy.DIZV import DIZV
from ..Classes.Legacy.CameraLegacy import CameraLegacy
from ..Classes.Legacy.RLC import RLC
from ..Classes.Legacy.ANPRPaal import ANPRPaal
from ..Classes.Legacy.SNC import SNC
from ..Classes.Legacy.VMS import VMS



from abc import abstractmethod

from otlmow_model.OtlmowModel.GeometrieTypes.AbstracteGeometrie import AbstracteGeometrie


class VlakGeometrie(AbstracteGeometrie):
    @abstractmethod
    def __init__(self):
        super().__init__()
        self._geometry_types.append('POLYGON Z')



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.NaampadObject import NaampadObject
from ...Datatypes.KlBinnenverlichtingstoestelSchakelwijze import KlBinnenverlichtingstoestelSchakelwijze
from ...Datatypes.KlBinnenverlichtingstoestelSoortLamp import KlBinnenverlichtingstoestelSoortLamp
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Binnenverlichtingstoestel(NaampadObject, PuntGeometrie):
    """Een verlichtingstoestel dat binnen in een gebouw geplaatst wordt. Een verlichtingstoestel is de combinatie van de lamp en de armatuur."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AfmetingenDiepCBWand', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BalkGK', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Betonfundering', direction='u', deprecated='2.0.0')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElement', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructiefObject', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#DamplankAbstracte', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Fundering', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KlassiekeFundering', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#StalenProfiel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Aanslagbalk', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Balans', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Balansarm', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Balk', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#BeweegbareWaterkerendeConstructie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Boog', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Breekbalk', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugligger', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Damwand', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#DraagstructuurBWCTWC', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#DrogePompkelder', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Gewelf', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Gording', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Hameipoort', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Hameistijl', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Hefportiek', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Heftoren', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#HorizontaleConstructieplaat', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kabelkoker', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kesp', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kolom', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Koppelbalk', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#MVPaal', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pyloon', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Randprofiel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#StalenFunderingsprofiel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Tegengewichtkist', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#TijdelijkeWaterkerendeConstructie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VakwerkElement', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Verdeelbalk', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Wand', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Windverband', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Wrijfbalk', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Baret', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenBoorpaal', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenConstructieObject', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenDamplank', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenHeipaal', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenPlaat', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenPredal', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenProfiel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenSchroefpaal', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Breedplaat', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#CFAPaal', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#CementBentonietwand', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ConstructieSokkel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Damwand', direction='u', deprecated='2.8.0')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Diepwand', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Druklaag', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#FunderingOpStaal', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Funderingsmassief', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Funderingspaal', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Funderingsplaat', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Funderingsput', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Funderingszool', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Grindkern', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Groutpaal', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoutenConstructieprofiel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoutenDamplank', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoutenHeipaal', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Injectiepaal', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KunststoffenDamplank', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Metselwerk', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Micropaal', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#NietStandaardStalenProfiel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PlintGC', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SoilmixwandElement', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#StalenBuispaal', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#StalenConstructieObject', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#StalenDamplank', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#StalenPlaat', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#StalenSchroefpaal', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#StandaardStalenProfiel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verankeringsmassief', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voorzetconstructie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#BinnenverlichtingGroep', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pompstation', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Vluchtganginrichting', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#TGCUitbreidingsModule', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Toegangscontroller', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Laagspanningsbord', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stroomkring', direction='i')  # i = direction: incoming

        self._schakelwijze = OTLAttribuut(field=KlBinnenverlichtingstoestelSchakelwijze,
                                          naam='schakelwijze',
                                          label='schakelwijze',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel.schakelwijze',
                                          definition='Geeft aan hoe het toestel aan- en uitgeschakeld wordt.',
                                          owner=self)

        self._soortLamp = OTLAttribuut(field=KlBinnenverlichtingstoestelSoortLamp,
                                       naam='soortLamp',
                                       label='soort lamp',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel.soortLamp',
                                       definition='Geeft aan welke soort lamp er gebruikt wordt in het binnenverlichtingstoestel.',
                                       owner=self)

    @property
    def schakelwijze(self) -> str:
        """Geeft aan hoe het toestel aan- en uitgeschakeld wordt."""
        return self._schakelwijze.get_waarde()

    @schakelwijze.setter
    def schakelwijze(self, value):
        self._schakelwijze.set_waarde(value, owner=self)

    @property
    def soortLamp(self) -> str:
        """Geeft aan welke soort lamp er gebruikt wordt in het binnenverlichtingstoestel."""
        return self._soortLamp.get_waarde()

    @soortLamp.setter
    def soortLamp(self, value):
        self._soortLamp.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlConstructie(KeuzelijstField):
    """De mogelijke beweegbare delen."""
    naam = 'KlConstructie'
    label = 'Beweegbaar deel'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#KlConstructie'
    definition = 'De mogelijke beweegbare delen.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlConstructie'
    options = {
        'deur': KeuzelijstWaarde(invulwaarde='deur',
                                 label='deur',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlConstructie/deur'),
        'klep': KeuzelijstWaarde(invulwaarde='klep',
                                 label='klep',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlConstructie/klep'),
        'schuif': KeuzelijstWaarde(invulwaarde='schuif',
                                   label='schuif',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlConstructie/schuif')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from abc import abstractmethod
from ...Datatypes.DteIPv4Adres import DteIPv4Adres, DteIPv4AdresWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class IpAdresObject(PuntGeometrie):
    """Abstracte klasse voor een IP4 adres."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#IpAdresObject'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self._ipAdres = OTLAttribuut(field=DteIPv4Adres,
                                     naam='ipAdres',
                                     label='ip adres',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#IpAdresObject.ipAdres',
                                     definition='Netwerkadresgegevens of ip-adres van het element.',
                                     owner=self)

    @property
    def ipAdres(self) -> DteIPv4AdresWaarden:
        """Netwerkadresgegevens of ip-adres van het element."""
        return self._ipAdres.get_waarde()

    @ipAdres.setter
    def ipAdres(self, value):
        self._ipAdres.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlSimkaarttype(KeuzelijstField):
    """De mogelijk types van een simkaart."""
    naam = 'KlSimkaarttype'
    label = 'Simkaarttype'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlSimkaarttype'
    definition = 'De mogelijk types van een simkaart.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlSimkaarttype'
    options = {
        'geen': KeuzelijstWaarde(invulwaarde='geen',
                                 label='geen',
                                 status='ingebruik',
                                 definitie='geen simkaart',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSimkaarttype/geen'),
        'olu': KeuzelijstWaarde(invulwaarde='olu',
                                label='OLU',
                                status='ingebruik',
                                definitie='OLU simkaart',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSimkaarttype/olu'),
        'sim-olu': KeuzelijstWaarde(invulwaarde='sim-olu',
                                    label='SIM-OLU',
                                    status='ingebruik',
                                    definitie='SIM-OLU',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSimkaarttype/sim-olu'),
        'standaard': KeuzelijstWaarde(invulwaarde='standaard',
                                      label='standaard',
                                      status='ingebruik',
                                      definitie='standaard simkaart',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSimkaarttype/standaard')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from ...Classes.Abstracten.Verkeerslicht import Verkeerslicht


# Generated with OTLClassCreator. To modify: extend, do not edit
class VerkeerslichtOranjegeel(Verkeerslicht):
    """Een lichtbron met oranje-gele kleur om de weggebruikers aan te geven dat het verboden is de stopstreep of, zo er geen stopstreep is, het verkeerslicht zelf, voorbij te rijden, tenzij de bestuurder bij het aangaan van dat licht zo dicht genaderd is, dat hij niet meer op voldoende veilige wijze kan stoppen. Als dit licht bij een kruispunt geplaatst is, mag de bestuurder, die de stopstreep of het licht in dergelijke omstandigheden voorbijgereden is, het kruispunt evenwel slechts oversteken op voorwaarde de andere weggebruikers niet in gevaar te brengen"""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerkeerslichtOranjegeel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn', direction='u')  # u = unidirectional



# coding=utf-8
from ...Classes.ImplementatieElement.NietDirectioneleRelatie import NietDirectioneleRelatie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Bevestiging(NietDirectioneleRelatie):
    """Deze relatie geeft aan dat twee onderdelen direct fysiek op elkaar bevestigd zijn. Dit kan zowel aan de buitenkant als aan de binnenkant zijn zoals bv. een camera aan een paal of een laagspanningsbord in een kast. Daarnaast omvat deze relatie ook situaties waarin onderdelen niet direct, maar wel structureel of functioneel met elkaar verbonden zijn op een manier die bevestiging impliceert, bv. een trap die eindigt net onder een voetgangersbrug zonder fysieke bevestiging. Deze relatie heeft geen richting."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlMateriaalAfdichtingsvoorziening(KeuzelijstField):
    """De mogelijke materialen waaruit een afdichtingsvoorziening bestaat."""
    naam = 'KlMateriaalAfdichtingsvoorziening'
    label = 'Materiaal afdichtingsvoorziening'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlMateriaalAfdichtingsvoorziening'
    definition = 'De mogelijke materialen waaruit een afdichtingsvoorziening bestaat.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlMateriaalAfdichtingsvoorziening'
    options = {
        'hout': KeuzelijstWaarde(invulwaarde='hout',
                                 label='hout',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMateriaalAfdichtingsvoorziening/hout'),
        'kunststof': KeuzelijstWaarde(invulwaarde='kunststof',
                                      label='kunststof',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMateriaalAfdichtingsvoorziening/kunststof'),
        'rubber': KeuzelijstWaarde(invulwaarde='rubber',
                                   label='rubber',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMateriaalAfdichtingsvoorziening/rubber')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

